@@ -22,7 +22,7 @@ import warnings
 from datetime import datetime
 from typing import TYPE_CHECKING, List, Optional, ClassVar, Union, Tuple, Any
 
-from telegram import ChatPhoto, TelegramObject, constants
+from telegram import ChatPhoto, TelegramObject, constants, MenuButton
 from telegram.utils.types import JSONDict, FileInput, ODVInput, DVInput
 from telegram.utils.deprecate import TelegramDeprecationWarning
 
@@ -116,6 +116,16 @@ class Chat(TelegramObject):
             chats. Returned only in :meth:`telegram.Bot.get_chat`.
         location (:class:`telegram.ChatLocation`, optional): For supergroups, the location to which
             the supergroup is connected. Returned only in :meth:`telegram.Bot.get_chat`.
+        join_to_send_messages (:obj:`bool`, optional): :obj:`True`, if users need to join the
+            supergroup before they can send messages. Returned only in
+            :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.13
+        join_by_request (:obj:`bool`, optional): :obj:`True`, if all users directly joining the
+            supergroup need to be approved by supergroup administrators. Returned only in
+            :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.13
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
@@ -160,7 +170,16 @@ class Chat(TelegramObject):
             chats. Returned only in :meth:`telegram.Bot.get_chat`.
         location (:class:`telegram.ChatLocation`): Optional. For supergroups, the location to which
             the supergroup is connected. Returned only in :meth:`telegram.Bot.get_chat`.
+        join_to_send_messages (:obj:`bool`): Optional. :obj:`True`, if users need to join the
+            supergroup before they can send messages. Returned only in
+            :meth:`telegram.Bot.get_chat`.
 
+            .. versionadded:: 13.13
+        join_by_request (:obj:`bool`): Optional. :obj:`True`, if all users directly joining the
+            supergroup need to be approved by supergroup administrators. Returned only in
+            :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.13
     """
 
     __slots__ = (
@@ -186,6 +205,8 @@ class Chat(TelegramObject):
         'message_auto_delete_time',
         'has_protected_content',
         'has_private_forwards',
+        'join_to_send_messages',
+        'join_by_request',
         '_id_attrs',
     )
 
@@ -226,6 +247,8 @@ class Chat(TelegramObject):
         message_auto_delete_time: int = None,
         has_private_forwards: bool = None,
         has_protected_content: bool = None,
+        join_to_send_messages: bool = None,
+        join_by_request: bool = None,
         **_kwargs: Any,
     ):
         # Required
@@ -254,6 +277,8 @@ class Chat(TelegramObject):
         self.can_set_sticker_set = can_set_sticker_set
         self.linked_chat_id = linked_chat_id
         self.location = location
+        self.join_to_send_messages = join_to_send_messages
+        self.join_by_request = join_by_request
 
         self.bot = bot
         self._id_attrs = (self.id,)
@@ -590,6 +615,7 @@ class Chat(TelegramObject):
         is_anonymous: bool = None,
         can_manage_chat: bool = None,
         can_manage_voice_chats: bool = None,
+        can_manage_video_chats: bool = None,
     ) -> bool:
         """Shortcut for::
 
@@ -600,6 +626,9 @@ class Chat(TelegramObject):
 
         .. versionadded:: 13.2
 
+        ..versionchanged:: 13.12
+            Since Bot API 6.0, voice chat was renamed to video chat.
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
@@ -620,6 +649,7 @@ class Chat(TelegramObject):
             is_anonymous=is_anonymous,
             can_manage_chat=can_manage_chat,
             can_manage_voice_chats=can_manage_voice_chats,
+            can_manage_video_chats=can_manage_video_chats,
         )
 
     def restrict_member(
@@ -1813,3 +1843,61 @@ class Chat(TelegramObject):
         return self.bot.decline_chat_join_request(
             chat_id=self.id, user_id=user_id, timeout=timeout, api_kwargs=api_kwargs
         )
+
+    def set_menu_button(
+        self,
+        menu_button: MenuButton = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+             bot.set_chat_menu_button(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.set_chat_menu_button`.
+
+        Caution:
+            Can only work, if the chat is a private chat.
+
+        ..seealso:: :meth:`get_menu_button`
+
+        .. versionadded:: 13.12
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+        """
+        return self.bot.set_chat_menu_button(
+            chat_id=self.id,
+            menu_button=menu_button,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
+
+    def get_menu_button(
+        self,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> MenuButton:
+        """Shortcut for::
+
+             bot.get_chat_menu_button(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.set_chat_menu_button`.
+
+        Caution:
+            Can only work, if the chat is a private chat.
+
+        ..seealso:: :meth:`set_menu_button`
+
+        .. versionadded:: 13.12
+
+        Returns:
+            :class:`telegram.MenuButton`: On success, the current menu button is returned.
+        """
+        return self.bot.get_chat_menu_button(
+            chat_id=self.id,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
