@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -60,6 +60,17 @@ class Venue(TelegramObject):
 
     """
 
+    __slots__ = (
+        'google_place_type',
+        'location',
+        'title',
+        'address',
+        'foursquare_type',
+        'foursquare_id',
+        'google_place_id',
+        '_id_attrs',
+    )
+
     def __init__(
         self,
         location: Location,
@@ -85,7 +96,8 @@ class Venue(TelegramObject):
 
     @classmethod
     def de_json(cls, data: Optional[JSONDict], bot: 'Bot') -> Optional['Venue']:
-        data = cls.parse_data(data)
+        """See :meth:`telegram.TelegramObject.de_json`."""
+        data = cls._parse_data(data)
 
         if not data:
             return None
