@@ -79,6 +79,13 @@ class User(TelegramObject):
         supports_inline_queries (:obj:`str`, optional): :obj:`True`, if the bot supports inline
             queries. Returned only in :attr:`telegram.Bot.get_me` requests.
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
+        is_premium (:obj:`bool`, optional): :obj:`True`, if this user is a Telegram Premium user.
+
+            .. versionadded:: 13.13
+        added_to_attachment_menu (:obj:`bool`, optional): :obj:`True`, if this user added
+            the bot to the attachment menu.
+
+            .. versionadded:: 13.13
 
     Attributes:
         id (:obj:`int`): Unique identifier for this user or bot.
@@ -94,6 +101,14 @@ class User(TelegramObject):
         supports_inline_queries (:obj:`str`): Optional. :obj:`True`, if the bot supports inline
             queries. Returned only in :attr:`telegram.Bot.get_me` requests.
         bot (:class:`telegram.Bot`): Optional. The Bot to use for instance methods.
+        is_premium (:obj:`bool`): Optional. :obj:`True`, if this user is a Telegram
+            Premium user.
+
+            .. versionadded:: 13.13
+        added_to_attachment_menu (:obj:`bool`): Optional. :obj:`True`, if this user added
+            the bot to the attachment menu.
+
+            .. versionadded:: 13.13
 
     """
 
@@ -108,6 +123,8 @@ class User(TelegramObject):
         'id',
         'bot',
         'language_code',
+        'is_premium',
+        'added_to_attachment_menu',
         '_id_attrs',
     )
 
@@ -123,6 +140,8 @@ class User(TelegramObject):
         can_read_all_group_messages: bool = None,
         supports_inline_queries: bool = None,
         bot: 'Bot' = None,
+        is_premium: bool = None,
+        added_to_attachment_menu: bool = None,
         **_kwargs: Any,
     ):
         # Required
@@ -136,6 +155,8 @@ class User(TelegramObject):
         self.can_join_groups = can_join_groups
         self.can_read_all_group_messages = can_read_all_group_messages
         self.supports_inline_queries = supports_inline_queries
+        self.is_premium = is_premium
+        self.added_to_attachment_menu = added_to_attachment_menu
         self.bot = bot
 
         self._id_attrs = (self.id,)
