@@ -943,6 +943,32 @@ class TestFilters:
         assert Filters.status_update.voice_chat_participants_invited(update)
         update.message.voice_chat_participants_invited = None
 
+        # same as above, just with video instead of voice.
+        update.message.video_chat_scheduled = 'scheduled'
+        assert Filters.status_update(update)
+        assert Filters.status_update.video_chat_scheduled(update)
+        update.message.video_chat_scheduled = None
+
+        update.message.video_chat_started = 'hello'
+        assert Filters.status_update(update)
+        assert Filters.status_update.video_chat_started(update)
+        update.message.video_chat_started = None
+
+        update.message.video_chat_ended = 'bye'
+        assert Filters.status_update(update)
+        assert Filters.status_update.video_chat_ended(update)
+        update.message.video_chat_ended = None
+
+        update.message.video_chat_participants_invited = 'invited'
+        assert Filters.status_update(update)
+        assert Filters.status_update.video_chat_participants_invited(update)
+        update.message.video_chat_participants_invited = None
+
+        update.message.web_app_data = 'data'
+        assert Filters.status_update(update)
+        assert Filters.status_update.web_app_data(update)
+        update.message.web_app_data = None
+
     def test_filters_forwarded(self, update):
         assert not Filters.forwarded(update)
         update.message.forward_date = datetime.datetime.utcnow()
@@ -1163,6 +1189,19 @@ class TestFilters:
         with pytest.raises(RuntimeError, match='Cannot set name'):
             f.name = 'foo'
 
+    def test_filters_user_attributes(self, update):
+        assert not Filters.user_attachment(update)
+        assert not Filters.premium_user(update)
+        update.message.from_user.added_to_attachment_menu = True
+        assert Filters.user_attachment(update)
+        assert not Filters.premium_user(update)
+        update.message.from_user.is_premium = True
+        assert Filters.user_attachment(update)
+        assert Filters.premium_user(update)
+        update.message.from_user.added_to_attachment_menu = False
+        assert not Filters.user_attachment(update)
+        assert Filters.premium_user(update)
+
     def test_filters_chat_init(self):
         with pytest.raises(RuntimeError, match='in conjunction with'):
             Filters.chat(chat_id=1, username='chat')
